CustomOptions class

Constructors

CustomOptions({String? bordercolor, String? bgcolor, String? headertextcolor, String? header1textcolor, String? iconcolor, String? iconbgcolor, String? adbadgebgcolor, String? adbadgetextcolor, String? adbadgebordercolor, String? buttoncolor, String? buttontxtcolor})
CustomOptions.fromJson(Map<String, dynamic> json)

Properties

adbadgebgcolor String?
getter/setter pair
adbadgebordercolor String?
getter/setter pair
adbadgetextcolor String?
getter/setter pair
bgcolor String?
getter/setter pair
bordercolor String?
getter/setter pair
buttoncolor String?
getter/setter pair
buttontxtcolor String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
header1textcolor String?
getter/setter pair
headertextcolor String?
getter/setter pair
iconbgcolor String?
getter/setter pair
iconcolor String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toMap() Map<String, String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited