QurekaAds class
Constructors
Properties
-
adsQurekaBannerList
↔ List<
String> ? -
getter/setter pair
-
adsQurekaList
↔ List<
String> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerText ↔ String?
-
getter/setter pair
- headerText1 ↔ String?
-
getter/setter pair
- qurekaAdText ↔ String?
-
getter/setter pair
- qurekaBorderColor ↔ String?
-
getter/setter pair
- qurekaButtonText ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showIcon ↔ bool?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited