PluginCodelab class

Constructors

PluginCodelab()
factory

Properties

admodel AdModel?
getter/setter pair
appLifecycleReactor AppLifecycleReactor?
getter/setter pair
appOpenAdManager AppOpenAdManager?
getter/setter pair
bannerManager BannerAdManager
final
hashCode int
The hash code for this object.
no setterinherited
interstitialAds InterstitialAds?
getter/setter pair
manager NativeAdManager
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

adsONorOFf() Future
fetchData() Future
getCallAppOpenAds(dynamic context, {VoidCallback? onAdDismissed}) Future
getCallCloseInterstitialAds(dynamic j) Future
getCallInterstitialAds(dynamic i) Future
getIsFromRefferal() Future<bool>
getOrCreatePersistentUniqueId() Future<String>
initPlatformState() Future
loadRewardAds(Function callback) → dynamic
native(Function callBack, CustomNativeAdType type) Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preloadAds([CustomNativeAdType? type]) → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited